@@ -1,27 +1,14 @@
-__version__ = "1.11.0"
+__version__ = "2.0.0"
 
-from .data import (
-    ATTR_HW_VERSION,
-    ATTR_MANUFACTURER,
-    ATTR_MODEL,
-    ATTR_NAME,
-    ATTR_SW_VERSION,
-    SensorData,
-    SensorDeviceInfo,
-    SensorUpdate,
-)
+from .data import SensorData, SensorDeviceInfo, SensorUpdate
 from .description import SensorDescription
 from .device import DeviceKey
 from .device_class import DeviceClass
 from .library import SensorLibrary
+from .units import Units
 from .value import SensorValue
 
 __all__ = [
-    "ATTR_HW_VERSION",
-    "ATTR_MANUFACTURER",
-    "ATTR_MODEL",
-    "ATTR_NAME",
-    "ATTR_SW_VERSION",
     "DeviceClass",
     "DeviceKey",
     "SensorData",
@@ -30,4 +17,5 @@ __all__ = [
     "SensorLibrary",
     "SensorUpdate",
     "SensorValue",
+    "Units",
 ]
